@@ -1,4 +1,5 @@
 from wpimath.geometry import Pose3d
+from wpilib import Timer
 
 
 class VisionEstimator:
@@ -9,10 +10,10 @@ class VisionEstimator:
     def __init__(self):
         pass
 
-    def get_estimated_robot_pose(self) -> list[Pose3d] | None:
+    def get_estimated_robot_pose(self) -> list[Pose3d, float] | None:
         """
         Returns the robot's pose relative to the field, estimated by the vision system. Override this method.
         :return: Vision system estimate of robot pose.
-        :rtype: Pose3d | None
+        :rtype: list[Pose3d, seconds: float] | None
         """
         raise NotImplementedError
