@@ -277,23 +277,23 @@ class SwerveDrivetrain(Subsystem):
                 vel[0], vel[1], angular_vel
             ))
 
-        module_states = (
-            self.n_00.get_node_state(),
-            self.n_01.get_node_state(),
-            self.n_10.get_node_state(),
-            self.n_11.get_node_state()
+        module_positions = (
+            self.n_00.get_node_position(),
+            self.n_01.get_node_position(),
+            self.n_10.get_node_position(),
+            self.n_11.get_node_position()
         )
 
         self.odometry.update(
             self.get_heading(),
-            *module_states
+            *module_positions
         )
 
         self.odometry_estimator.update(
             self.get_heading(),
-            module_states
+            module_positions
         )
-        self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_states)
+        self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_positions)
 
     def stop(self):
         """
